==> cra-template-ui5-webcomponents-react-typescript-seed-1.0.0.tgz: package/README.md <==
### <img src="https://simpleicons.org/icons/react.svg" width="20" alt="React Icon"> <img src="https://simpleicons.org/icons/typescript.svg" width="20" alt="Typescript Icon"> UI5 Web Components React Typescript Seed

Includes the following dependencies configured:

- Typescript
- UI5 Webcomponents
- React-JSS
- Prettier
- Eslint with Airbnb style guide
- i18next
- Husky linter on pre-commit hook
- Axios
- Jest
- Enzyme for snapshot testing

#### How to Use

To create an app using this template, just open a terminal and run:

- `yarn create react-app PROJECT_NAME --template ui5-webcomponents-react-typescript-seed`

or

- `npx create-react-app PROJECT_NAME --template ui5-webcomponents-react-typescript-seed`

## Available Scripts

In the project directory, you can run:

### `yarn start`

Runs the app in the development mode.<br />
Open [http://localhost:3000](http://localhost:3000) to view it in the browser.

The page will reload if you make edits.<br />
You will also see any lint errors in the console.

### `yarn test`

Launches the test runner in the interactive watch mode.<br />
See the section about [running tests](https://facebook.github.io/create-react-app/docs/running-tests) for more information.

### `yarn build`

Builds the app for production to the `build` folder.<br />
It correctly bundles React in production mode and optimizes the build for the best performance.

The build is minified and the filenames include the hashes.<br />
Your app is ready to be deployed!

See the section about [deployment](https://facebook.github.io/create-react-app/docs/deployment) for more information.

## Learn More

You can learn more in the [Create React App documentation](https://facebook.github.io/create-react-app/docs/getting-started).

To learn React, check out the [React documentation](https://reactjs.org/).

==> cra-template-ui5-webcomponents-react-typescript-seed-1.0.1.tgz: package/README.md <==
# <img src="https://simpleicons.org/icons/react.svg" width="20" alt="React Icon"> <img src="https://simpleicons.org/icons/typescript.svg" width="20" alt="Typescript Icon"> UI5 Web Components React Typescript Seed

Includes the following dependencies configured:

- Typescript
- UI5 Webcomponents
- React-JSS
- Prettier
- Eslint with Airbnb style guide
- i18next
- Husky linter on pre-commit hook
- Axios
- Jest
- Enzyme for snapshot testing

### How to Use

To create an app using this template, just open a terminal and run:

- `yarn create react-app PROJECT_NAME --template ui5-webcomponents-react-typescript-seed`

or

- `npx create-react-app PROJECT_NAME --template ui5-webcomponents-react-typescript-seed`

### Available Scripts

In the project directory, you can run:

### `yarn start`

Runs the app in the development mode.<br />
Open [http://localhost:3000](http://localhost:3000) to view it in the browser.

The page will reload if you make edits.<br />
You will also see any lint errors in the console.

### `yarn test`

Launches the test runner in the interactive watch mode.<br />
See the section about [running tests](https://facebook.github.io/create-react-app/docs/running-tests) for more information.

### `yarn build`

Builds the app for production to the `build` folder.<br />
It correctly bundles React in production mode and optimizes the build for the best performance.

The build is minified and the filenames include the hashes.<br />
Your app is ready to be deployed!

See the section about [deployment](https://facebook.github.io/create-react-app/docs/deployment) for more information.

## Learn More

You can learn more in the [Create React App documentation](https://facebook.github.io/create-react-app/docs/getting-started).

To learn React, check out the [React documentation](https://reactjs.org/).
